Stocks ML
===================================

A project to replace the MeasurementSet and Image data manipulation and processing
infrastructure of CASA with a parallel, scalable, and largely off-the-shelf solution.

.. toctree::
   :hidden:
   :maxdepth: 3

   quick_start
   api